%
%
%   Data Acquisition Toolbox - Standardaufgaben
%
%   Hochschule Mnchen
%   Labor fr Maschinendynmik
%   Dipl.-Ing. Armin Rohnen LbA
%
%   Mnchen, 21. Dezember 2016
%
%   -----------------------------------------------------------------------

clear;
daq.getDevices

%{
Data acquisition devices:

index Vendor Device ID              Description            
----- ------ ---------- -----------------------------------
1     ni     cDAQ2Mod1  National Instruments NI 9219
2     ni     cDAQ2Mod2  National Instruments NI 9219
3     ni     cDAQ2Mod7  National Instruments NI 9234
4     ni     cDAQ2Mod8  National Instruments NI 9234
5     ni     cDAQ2Mod9  National Instruments NI 9234
6     ni     cDAQ2Mod10 National Instruments NI 9234
7     ni     cDAQ2Mod11 National Instruments NI 9215
8     ni     cDAQ2Mod12 National Instruments NI 9237 (DSUB)
9     ni     cDAQ2Mod13 National Instruments NI 9263
10    ni     cDAQ2Mod14 National Instruments NI 9401


ans = 

ni: National Instruments NI 9219 (Device ID: 'cDAQ2Mod1')
   Analog input subsystem supports:
      9 ranges supported
      Rates from 0.1 to 100.0 scans/sec
      4 channels ('ai0','ai1','ai2','ai3')
      'Voltage','Current','Thermocouple','RTD','Bridge' measurement types
   
This module is in slot 1 of the 'cDAQ-9179' chassis with the name 'cDAQ2'.

Properties, Methods, Events

%}

messgeraet = daq.createSession('ni');

ch(1)=addAnalogInputChannel(messgeraet, 'cDAQ2Mod1', 'ai0', 'Voltage');
ch(2)=addAnalogInputChannel(messgeraet, 'cDAQ2Mod1', 'ai1', 'Current');
ch(3)=addAnalogInputChannel(messgeraet, 'cDAQ2Mod1', 'ai2', 'Thermocouple');
ch(4)=addAnalogInputChannel(messgeraet, 'cDAQ2Mod1', 'ai3', 'Bridge');

%{
ch(1).Device

ans = 

ni: National Instruments NI 9219 (Device ID: 'cDAQ2Mod1')
   Analog input subsystem supports:
      9 ranges supported
      Rates from 0.1 to 100.0 scans/sec
      4 channels ('ai0','ai1','ai2','ai3')
      'Voltage','Current','Thermocouple','RTD','Bridge' measurement types
   
This module is in slot 1 of the 'cDAQ-9179' chassis with the name 'cDAQ2'.

%}
ch(1).Range=[-1, 1]

%{
ch = 

Number of channels: 4
   index Type  Device   Channel MeasurementType              Range             Name
   ----- ---- --------- ------- ---------------- ----------------------------- ----
   1     ai   cDAQ2Mod1 ai0     Voltage (Diff)   -1.0 to +1.0 Volts
   2     ai   cDAQ2Mod1 ai1     Current          -0.025 to +0.025 A
   3     ai   cDAQ2Mod1 ai2     Thermocouple     0 to +750 Celsius
   4     ai   cDAQ2Mod1 ai3     Bridge (Unknown) -0.025 to +0.025 VoltsPerVolt
%}

ch(1).Name = 'Spannungsmessstelle'
%{
ch = 

Number of channels: 4
   index Type  Device   Channel MeasurementType              Range                    Name        
   ----- ---- --------- ------- ---------------- ----------------------------- -------------------
   1     ai   cDAQ2Mod1 ai0     Voltage (Diff)   -1.0 to +1.0 Volts            Spannungsmessstelle
   2     ai   cDAQ2Mod1 ai1     Current          -0.025 to +0.025 A
   3     ai   cDAQ2Mod1 ai2     Thermocouple     0 to +750 Celsius
   4     ai   cDAQ2Mod1 ai3     Bridge (Unknown) -0.025 to +0.025 VoltsPerVolt


ch(1).Coupling='AC';
removeChannel(messgeraet,index);
%}

data = inputSingleScan(messgeraet);

%{
data =

    0.0196    0.0000
%}
[data,triggerTime] = inputSingleScan(messgeraet);
%{
data =

   -0.0027    0.0000


triggerTime =

   7.3669e+05
%}

ch(3)=addAnalogInputChannel(messgeraet, 'cDAQ2Mod1', 'ai2', 'Thermocouple');
set(ch(3));
%{
           Units: [ Celsius | Fahrenheit | Kelvin | Rankine ]
ThermocoupleType: [ Unknown | J | K | N | R | S | T | B | E ]
           Range: 0 to +750 Celsius
            Name: {}
   ADCTimingMode: [ HighResolution | HighSpeed | Best50HzRejection | Best60HzRejection ]
%}

ch(3).ThermocoupleType = 'K';
ch(3).Units = 'Celsius';
ch(3).ADCTimingMode = 'Best50HzRejection';

[data,triggerTime] = inputSingleScan(messgeraet);

%{
data =

   1.0e+13 *

   -0.0000    0.0000   -2.4570


triggerTime =

   7.3669e+05
%}

messgeraet2 = daq.createSession('ni');
ch(4)=addAnalogInputChannel(messgeraet2, 'cDAQ2Mod1', 'ai3', 'Bridge');
ch(4).BridgeMode = 'Half';
ch(4).NominalBridgeResistance = 120;
ch(4).Range = [-0.025, 0.025]
%{
ch = 

Number of channels: 4
   index Type  Device   Channel MeasurementType             Range                    Name        
   ----- ---- --------- ------- --------------- ----------------------------- -------------------
   1     ai   cDAQ2Mod1 ai0     Voltage (Diff)  -1.0 to +1.0 Volts            Spannungsmessstelle
   2     ai   cDAQ2Mod1 ai1     Current         -0.025 to +0.025 A
   3     ai   cDAQ2Mod1 ai2     Thermocouple    -200 to +1250 Celsius
   4     ai   cDAQ2Mod1 ai3     Bridge (Half)   -0.025 to +0.025 VoltsPerVolt


[data,triggerTime] = inputSingleScan(messgeraet2)

data =

   -0.0013


triggerTime =

   7.3669e+05

%}